Update rustfmt path

This CL updates the rustfmt path used in prepare_deployment.sh based on
https://groups.google.com/a/fuchsia.dev/g/rust-users/c/nNmnQtph1e8/m/5WXVTkOWBgAJ.

Change-Id: Ib990b4d2761936f16c244efdd4f0e6f16c79a9a6
Reviewed-on: https://fuchsia-review.googlesource.com/c/fidlbolt/+/578624
Reviewed-by: Yifei Teng <yifeit@google.com>
diff --git a/prepare_deployment.sh b/prepare_deployment.sh
index 828a366..cd149af 100755
--- a/prepare_deployment.sh
+++ b/prepare_deployment.sh
@@ -69,7 +69,7 @@
 fi
 
 # Source fx-env.sh to get the fx tool on the PATH.
 # Source vars.sh for FUCHSIA_BUILD_DIR and PREBUILT_RUST_TOOLS_DIR.
 # (Reset shell options before sourcing since vars.sh does not expect them.)
 set +ufo pipefail
 source "$FUCHSIA_DIR/scripts/fx-env.sh" || exit $?
@@ -101,7 +101,7 @@
 step "Copying binaries"
 cp "${binaries[@]/#/$FUCHSIA_BUILD_DIR/host_x64/}" \
     "$PREBUILT_CLANG_DIR/bin/clang-format" \
-    "$PREBUILT_RUST_TOOLS_DIR/bin/rustfmt" \
+    "$PREBUILT_RUST_DIR/bin/rustfmt" \
     deployment/bin
 
 step "Copying FIDL libraries"
@@ -144,7 +144,7 @@
     | awk 'NR==1{print $4;}'
 )
 readonly rustfmt_version=$(
-    "$PREBUILT_RUST_TOOLS_DIR/bin/rustfmt" --version \
+    "$PREBUILT_RUST_DIR/bin/rustfmt" --version \
     | awk 'NR==1{sub(/-.*/, "", $2); print $2}'
 )
@@ -69,7 +69,7 @@
 
 # Source fx-env.sh to get the fx tool on the PATH.
-# Source vars.sh for FUCHSIA_BUILD_DIR and PREBUILT_RUST_TOOLS_DIR.
+# Source vars.sh for FUCHSIA_BUILD_DIR and PREBUILT_RUST_DIR.
 # (Reset shell options before sourcing since vars.sh does not expect them.)
 set +ufo pipefail